@@ -1,6 +1,7 @@
 import requests
 import logging
-from expai.expai_model import ExpaiModelExplainer
+from expai.expai_explainer import ExpaiModelExplainer
+from expai.expai_fairness import ExpaiModelFairness
 from expai.utils import generate_response
 import io
 import pandas as pd
@@ -8,12 +9,12 @@ import ast
 
 
 class ExpaiProject:
-    def __init__(self, project_id: str, api_key: str, headers: dict, server_name: str, session):
+    def __init__(self, project_id: str, access_token: str, headers: dict, server_name: str, session):
 
         self.project_id = project_id
 
         self.server_name = server_name
-        self.api_key = api_key
+        self.access_token = access_token
 
         self.headers = headers
         
@@ -86,9 +87,9 @@ class ExpaiProject:
                 'output_classes_des': ','.join(str(e) for e in output_classes) if output_classes is not None else None}
 
         files = {'model_file': open(model_path, 'rb')}
-        headers = {'api_key': self.api_key}
+        headers = {'access_token': self.access_token}
 
-        response = self.sess.request("GET", self.server_name + "/api/projects/{}/model/create".format(self.project_id),
+        response = self.sess.request("POST", self.server_name + "/api/projects/{}/model/create".format(self.project_id),
                                     data=data, headers=headers, files=files)
 
         if response.ok:
@@ -130,7 +131,24 @@ class ExpaiProject:
             model_id = self._get_model_id_from_name(model_name)
 
         if model_id is not None:
-            return ExpaiModelExplainer(model_id, self.project_id, self.api_key, self.headers, self.server_name, self.sess, self)
+            return ExpaiModelExplainer(model_id, self.project_id, self.access_token, self.headers, self.server_name, self.sess, self)
+        else:
+            logging.error("We could not find your model. Please, check your name or try using model_id as parameter")
+
+    def get_model_fairness(self, model_name: str = None, model_id: str = None):
+        """
+        Get a Python object that will enable you to interact with a project and its models.
+        :param model_name: Name of the project
+        :param model_id: Id of the project (optional)
+        :return: ExpaiModel object
+        """
+        assert model_name is not None or model_id is not None, "You must provide a project name or project id"
+
+        if model_id is None:
+            model_id = self._get_model_id_from_name(model_name)
+
+        if model_id is not None:
+            return ExpaiModelFairness(model_id, self.project_id, self.access_token, self.headers, self.server_name, self.sess, self)
         else:
             logging.error("We could not find your model. Please, check your name or try using model_id as parameter")
 
@@ -213,7 +231,8 @@ class ExpaiProject:
 
     def create_sample(self, sample_path: str = None, sample_name: str = None, sample_separator: str = None, sample_target_col: str = None,
                       sample_encoding: str = 'utf-8', is_display = False, reference_sample_id: str = None, reference_sample_name: str = None,
-                      display_sample_id: str = None, display_sample_name: str = None, sample_summary: str = None):
+                      display_sample_id: str = None, display_sample_name: str = None, sample_summary: str = None, protected_columns: list = None,
+                      drop_columns: list = None):
         """
         Create a new sample for the project
         :param sample_target_col: target column for the model
@@ -247,13 +266,15 @@ class ExpaiProject:
                 "is_display": 1 if is_display is True else 0,
                 "original_sample_id": reference_sample_id,
                 "display_sample_id": display_sample_id,
-                'sample_summary_des': sample_summary}
+                'sample_summary_des': sample_summary,
+                'sample_protected_columns_des': ','.join(protected_columns) if protected_columns else None,
+                'sample_drop_columns_des': ','.join(drop_columns) if drop_columns else None}
 
         files = {'sample_file': open(sample_path, 'r', encoding=sample_encoding)}
 
-        headers = {'api_key': self.api_key}
+        headers = {'access_token': self.access_token}
 
-        response = self.sess.request("GET", self.server_name + "/api/projects/{}/sample/create".format(self.project_id),
+        response = self.sess.request("POST", self.server_name + "/api/projects/{}/sample/create".format(self.project_id),
                                     data=data, headers=headers, files=files)
 
         if response.ok:
@@ -330,7 +351,7 @@ class ExpaiProject:
 
         files = {'sample_file': open(sample_path, 'r', encoding=sample_encoding)}
 
-        headers = {'api_key': self.api_key}
+        headers = {'access_token': self.access_token}
 
         response = self.sess.request("POST", self.server_name + "/api/projects/{}/sample/{}/append".format(self.project_id, sample_id),
                                      headers=headers, files=files)
