@@ -1,12 +1,17 @@
 import logging
 
 
-def generate_response(response, to_return_key='value'):
+def generate_response(response, to_return_keys=['value']):
     if response.ok:
-        if to_return_key in response.json().keys():
-            return (response.json()[to_return_key])
-        elif 'message' in response.json().keys():
-            return (response.json()['message'])
+        output = {}
+        for key in to_return_keys:
+            if key in response.json().keys():
+                output[key] = response.json()[key]
+
+        if len(output.keys()) > 0:
+            return output
+        elif len(output.keys()) == 0 and 'message' in response.json().keys():
+            return response.json()['message']
         else:
             return True
     else:
